# Generated by Django 2.2.9 on 2020-02-04 11:08

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="TestKid",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("happy", models.BooleanField()),
                ("name", models.CharField(max_length=30)),
                ("age", models.IntegerField()),
                ("bio", models.TextField()),
                ("wanted_games_qtd", models.BigIntegerField()),
                ("birthday", models.DateField()),
                ("appointment", models.DateTimeField()),
            ],
        ),
    ]



from django.contrib import admin
from django.urls import include, path

from .views import home


admin.autodiscover()

urlpatterns = [
    path("", home, name="home"),
    # url(r'^demoproject/', include('demoproject.foo.urls')),
    # Uncomment the admin/doc line below to enable admin documentation:
    # url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
    path("admin_tools_stats/", include("admin_tools_stats.urls")),
    path("admin_tools/", include("admin_tools.urls")),
    path("admin/", admin.site.urls),
]



from django.contrib.auth.models import User
from django.test import Client, TestCase
from django.test.client import RequestFactory


class BaseSuperuserAuthenticatedClient(TestCase):
    """Common Authentication"""

    fixtures = ["auth_user"]
    username = "admin"

    def setUp(self):
        """To create admin user"""
        self.client = Client()

        self.user = User.objects.get(username=self.username)
        self.client.force_login(self.user)

        self.factory = RequestFactory()


class BaseUserAuthenticatedClient(BaseSuperuserAuthenticatedClient):
    username = "user_1"


def assertContainsAny(
    self,
    response,
    texts,
    status_code=200,
    msg_prefix="",
    html=False,
):
    total_count = 0
    for text in texts:
        args = self._assert_contains(response, text, status_code, msg_prefix, html)
        real_count = args[1]
        msg_prefix = args[2]
        total_count += real_count

    self.assertTrue(total_count != 0, f"None of the {texts} were found in the response: {response}")



# Generated by Django 3.2.10 on 2022-01-04 08:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("demoproject", "0003_testkid_author"),
    ]

    operations = [
        migrations.AddField(
            model_name="testkid",
            name="height",
            field=models.IntegerField(null=True),
        ),
    ]



import logging
import time
from collections import OrderedDict
from datetime import datetime
from typing import Dict, List, Optional, Union

from datetime_truncate import truncate
from django.contrib.auth.mixins import LoginRequiredMixin
from django.views.generic import TemplateView

from .models import DashboardStats, Interval, get_charts_timezone, truncate_ceiling


logger = logging.getLogger(__name__)


class AdminChartsView(TemplateView):
    template_name = "admin_tools_stats/admin_charts.js"


interval_dateformat_map_bar_chart = {
    "years": ("%Y", "%Y"),
    "quarters": ("%b %Y", "%b"),
    "months": ("%b %Y", "%b"),
    "weeks": ("%a %d %b %Y", "%W"),
    "days": ("%a %d %b %Y", "%a"),
    "hours": ("%a %d %b %Y %H:%S", "%H"),
}

interval_dateformat_map = {
    "years": ("%Y", "%Y"),
    "quarters": ("%b %Y", "%b %Y"),
    "months": ("%b %Y", "%b %Y"),
    "weeks": ("%W (%d %b %Y)", "%W"),
    "days": ("%a %d %b %Y", "%d %b %Y"),
    "hours": ("%a %d %b %Y %H:%S", "%H"),
}


def get_dateformat(interval: Interval, chart_type):
    if chart_type == "discreteBarChart":
        return interval_dateformat_map_bar_chart[interval.value]
    return interval_dateformat_map[interval.value]


def remove_multiple_keys(in_dict, entries_to_remove):
    for k in entries_to_remove:
        in_dict.pop(k, None)


class ChartDataView(TemplateView):
    template_name = "admin_tools_stats/chart_data.html"

    def get_context_data(
        self, *args, interval: Optional[Interval] = None, graph_key=None, **kwargs
    ):
        dashboard_stats = DashboardStats.objects.get(graph_key=graph_key)
        context = super().get_context_data(*args, **kwargs)

        if not (
            self.request.user.has_perm("admin_tools_stats.view_dashboardstats")
            or dashboard_stats.show_to_users
        ):
            context["error"] = (
                "You have no permission to view this chart. "
                "Check if you are logged in and have permission "
                "'admin_tools_stats | dashboard stats | Can view dashboard stats'"
            )
            context["graph_title"] = dashboard_stats.graph_title
            return context

        dict = self.request.GET
        configuration: Dict[str, Union[str, List[str]]] = {item: dict[item] for item in dict}
        remove_multiple_keys(configuration, ["csrfmiddlewaretoken", "_", "graph_key"])
        selected_interval: Interval = Interval(
            configuration.pop("select_box_interval", interval) or dashboard_stats.default_time_scale
        )
        operation = configuration.pop(
            "select_box_operation", dashboard_stats.type_operation_field_name
        )
        if not isinstance(operation, str):
            operation = None
        operation_field = configuration.pop(
            "select_box_operation_field", dashboard_stats.operation_field_name
        )
        if not isinstance(operation_field, str):
            operation_field = None
        context["chart_type"] = configuration.pop(
            "select_box_chart_type", dashboard_stats.default_chart_type
        )
        try:
            chart_tz = get_charts_timezone()
            time_since = datetime.strptime(str(configuration.pop("time_since")), "%Y-%m-%d")
            time_since = truncate(time_since, selected_interval.val())
            time_since = time_since.astimezone(chart_tz)

            time_until = datetime.strptime(str(configuration.pop("time_until")), "%Y-%m-%d")
            time_until = truncate_ceiling(time_until, selected_interval.val())
            time_until = time_until.astimezone(chart_tz)

            if time_since > time_until:
                context["error"] = "Time since is greater than time until"
                context["graph_title"] = dashboard_stats.graph_title
                return context

            if dashboard_stats.cache_values:
                get_time_series = dashboard_stats.get_multi_time_series_cached
            else:
                get_time_series = dashboard_stats.get_multi_time_series

            series = get_time_series(
                configuration,
                time_since,
                time_until,
                selected_interval,
                operation,
                operation_field,
                self.request.user,
            )
        except Exception as e:
            if "debug" in configuration:
                raise e
            context["error"] = str(e)
            context["graph_title"] = dashboard_stats.graph_title
            logger.exception(e)
            return context

        ydata_serie: Dict[str, List[int]] = {}
        names = {}
        xdata = []
        serie_i_map: Dict[str, int] = OrderedDict()
        for date in sorted(
            series.keys(),
            key=lambda d: datetime(d.year, d.month, d.day, getattr(d, "hour", 0)),
        ):
            xdata.append(int(time.mktime(date.timetuple()) * 1000))
            for key, value in series[date].items():
                if key not in serie_i_map:
                    serie_i_map[key] = len(serie_i_map)
                y_key = "y%i" % serie_i_map[key]
                if y_key not in ydata_serie:
                    ydata_serie[y_key] = []
                    names["name%i" % serie_i_map[key]] = str(key)
                ydata_serie[y_key].append(value if value else 0)

        context["extra"] = {
            "x_is_date": True,
            "tag_script_js": False,
        }

        if dashboard_stats.y_axis_format:
            context["extra"]["y_axis_format"] = dashboard_stats.y_axis_format

        if context["chart_type"] == "stackedAreaChart":
            context["extra"]["use_interactive_guideline"] = True

        tooltip_date_format, context["extra"]["x_axis_format"] = get_dateformat(
            selected_interval, context["chart_type"]
        )

        extra_serie = {
            "tooltip": {"y_start": "", "y_end": ""},
            "date_format": tooltip_date_format,
        }

        context["values"] = {
            "x": xdata,
            "name1": selected_interval,
            **ydata_serie,
            **names,
            "extra1": extra_serie,
        }

        context["chart_container"] = "chart_container_" + graph_key
        return context


class ChartsMixin:
    def get_charts_query(self):
        query = DashboardStats.objects.order_by("graph_title").all()
        if not self.request.user.has_perm("admin_tools_stats.view_dashboardstats"):
            query = query.filter(show_to_users=True)
        return query


class AnalyticsView(LoginRequiredMixin, ChartsMixin, TemplateView):
    def get_template_names(self):
        if self.request.user.has_perm("admin_tools_stats.view_dashboardstats"):
            return "admin_tools_stats/analytics.html"
        return "admin_tools_stats/analytics_user.html"

    def get_context_data(self, *args, **kwargs):
        context_data = super().get_context_data(*args, **kwargs)
        context_data["nonuser_charts"] = self.get_charts_query().filter(show_to_users=False)
        context_data["charts"] = self.get_charts_query()
        return context_data


class AnalyticsChartView(LoginRequiredMixin, ChartsMixin, TemplateView):
    template_name = "admin_tools_stats/analytics_chart.html"

    def get_context_data(self, *args, graph_key=None, **kwargs):
        context_data = super().get_context_data(*args, **kwargs)
        context_data["chart"] = self.get_charts_query().get(graph_key=graph_key)
        return context_data



# Generated by Django 3.1.5 on 2021-02-21 11:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("demoproject", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="testkid",
            name="appointment",
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name="testkid",
            name="birthday",
            field=models.DateField(null=True),
        ),
    ]



# Generated by Django 3.2.10 on 2021-12-28 06:27

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("demoproject", "0002_auto_20210221_0541"),
    ]

    operations = [
        migrations.AddField(
            model_name="testkid",
            name="author",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]



from .demoproject.settings import *  # noqa
from .demoproject.settings import INSTALLED_APPS


ROOT_URLCONF = "demoproject.demoproject.urls"
ADMIN_TOOLS_MENU = "demoproject.menu.CustomMenu"
ADMIN_TOOLS_INDEX_DASHBOARD = "demoproject.dashboard.CustomIndexDashboard"
ADMIN_TOOLS_APP_INDEX_DASHBOARD = "demoproject.dashboard.CustomAppIndexDashboard"

INSTALLED_APPS.remove("demoproject")
INSTALLED_APPS.append("demoproject.demoproject")

FIXTURE_DIRS = ("demoproject/demoproject/fixtures/",)



# Django settings for demoproject project.

import os
import sys
from typing import List


DEBUG = True

APPLICATION_DIR = os.path.dirname(globals()["__file__"])

PROJECT_ROOT = os.path.abspath(
    os.path.join(os.path.dirname(__file__), ".."),
)

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

if os.environ.get("DB_ENGINE") == "mysql":
    DATABASES = {
        "default": {
            "ENGINE": "django.db.backends.mysql",
            "NAME": "test_db",
            "USER": os.environ.get("MYSQL_USER", "root"),
            "PASSWORD": os.environ.get("MYSQL_PASSWORD", "password"),
            "HOST": "127.0.0.1",
            "PORT": 3306,
            "TEST": {
                "CHARSET": "utf8",
                "COLLATION": "utf8_general_ci",
            },
        },
    }
elif os.environ.get("DB_ENGINE") == "sqlite":
    if "test" in sys.argv:
        database_name = ""
    else:
        database_name = os.path.join(os.path.dirname(__file__), "database.db")
    DATABASES = {
        "default": {
            "ENGINE": "django.db.backends.sqlite3",
            "NAME": database_name,
        },
    }
elif os.environ.get("DB_ENGINE") == "postgres":
    DATABASES = {
        "default": {
            "ENGINE": "django.db.backends.postgresql",
            "NAME": os.environ.get("POSTGRES_NAME", "postgres"),
            "USER": os.environ.get("POSTGRES_USER", "postgres"),
            "PASSWORD": os.environ.get("POSTGRES_PASSWORD", "postgres"),
            "HOST": os.environ.get("POSTGRES_HOST", ""),
            "PORT": os.environ.get("POSTGRES_PORT", ""),
        },
    }


# Hosts/domain names that are valid for this site; required if DEBUG is False
# See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
ALLOWED_HOSTS: List[str] = []

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = "America/Chicago"

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = "en-us"

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = True

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/var/www/example.com/media/"
MEDIA_ROOT = ""

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://example.com/media/", "http://media.example.com/"
MEDIA_URL = ""

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/var/www/example.com/static/"
STATIC_ROOT = os.path.join(PROJECT_ROOT, "static")

# URL prefix for static files.
# Example: "http://example.com/static/", "http://static.example.com/"
STATIC_URL = "/static/"

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    "django.contrib.staticfiles.finders.FileSystemFinder",
    "django.contrib.staticfiles.finders.AppDirectoriesFinder",
    # 'django.contrib.staticfiles.finders.DefaultStorageFinder',
    "djangobower.finders.BowerFinder",
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = "sq)9^f#mf444c(#om$zpo0v!%y=%pqem*9s_qav93fwr_&x40u"

# List of callables that know how to import templates from various sources.
TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [os.path.join(APPLICATION_DIR, "templates")],
        "OPTIONS": {
            "debug": DEBUG,
            "loaders": [
                (
                    "django.template.loaders.cached.Loader",
                    [
                        "django.template.loaders.filesystem.Loader",
                        "django.template.loaders.app_directories.Loader",
                        "admin_tools.template_loaders.Loader",
                    ],
                ),
            ],
            "context_processors": [
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.debug",
                "django.template.context_processors.i18n",
                "django.template.context_processors.media",
                "django.template.context_processors.static",
                "django.template.context_processors.csrf",
                "django.template.context_processors.tz",
                "django.template.context_processors.request",
            ],
        },
    }
]


MIDDLEWARE = (
    "django.middleware.common.CommonMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    # Uncomment the next line for simple clickjacking protection:
    # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
)


ROOT_URLCONF = "demoproject.urls"

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = "demoproject.wsgi.application"

INSTALLED_APPS = [
    # admin tool apps
    "django_nvd3",
    "admin_tools_stats",
    "admin_tools",
    "admin_tools.theming",
    "admin_tools.menu",
    "admin_tools.dashboard",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "djangobower",
    "demoproject",
    # 'south',
]

# Django extensions
try:
    import django_extensions  # noqa
except ImportError:
    pass
else:
    INSTALLED_APPS = INSTALLED_APPS + ["django_extensions"]

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "filters": {
        "require_debug_false": {
            "()": "django.utils.log.RequireDebugFalse",
        },
    },
    "handlers": {
        "mail_admins": {
            "level": "ERROR",
            "filters": ["require_debug_false"],
            "class": "django.utils.log.AdminEmailHandler",
        },
    },
    "loggers": {
        "django.request": {
            "handlers": ["mail_admins"],
            "level": "ERROR",
            "propagate": True,
        },
    },
}


# Django-bower
# ------------

# Specifie path to components root (you need to use absolute path)
BOWER_COMPONENTS_ROOT = os.path.join(PROJECT_ROOT, "components")

BOWER_PATH = "/usr/local/bin/bower"

BOWER_INSTALLED_APPS = (
    "d3#3.3.13",
    "nvd3#1.7.1",
)

# DJANGO-ADMIN-TOOL
# =================
ADMIN_TOOLS_MENU = "menu.CustomMenu"
ADMIN_TOOLS_INDEX_DASHBOARD = "dashboard.CustomIndexDashboard"
ADMIN_TOOLS_APP_INDEX_DASHBOARD = "dashboard.CustomAppIndexDashboard"
ADMIN_MEDIA_PREFIX = "/static/admin/"

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"


# IMPORT LOCAL SETTINGS
# =====================
try:
    from settings_local import *  # noqa
except ImportError:
    pass



from django.db import models


class TestKid(models.Model):
    """
    Model class Kid of family app
    """

    happy = models.BooleanField()
    name = models.CharField(max_length=30)
    age = models.IntegerField()
    height = models.IntegerField(null=True)
    bio = models.TextField()
    wanted_games_qtd = models.BigIntegerField()
    birthday = models.DateField(null=True)
    appointment = models.DateTimeField(null=True)
    author = models.ForeignKey(
        "auth.User", on_delete=models.CASCADE, default=None, null=True, blank=True
    )
